@@ -4,7 +4,7 @@ package Dist::Zilla::MintingProfile::Author::ETHER;
 # ABSTRACT: Mint distributions like ETHER does
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.108';
+our $VERSION = '0.109';
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile';
@@ -42,7 +42,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.108
+version 0.109
 
 =head1 SYNOPSIS
 
@@ -112,7 +112,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-irc://irc.perl.org/#distzilla.
+L<irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
